/*
  uSD-to-Serial Interface

  Reads test.txt from a uSD card, if it exists, and send the contents out via serial

  Based on ReadWrite.ino example code from the SdFat library: https://github.com/greiman/SdFat
  
  SD card attached to SPI bus as follows:
  - CS pin 10
  - MOSI (DI) pin 11
  - MISO (DO) pin 12
  - CLK pin 13
  
 Created 26 May 2018 by Joe Grand [www.grandideastudio.com]
 
 This example code is in the public domain
 
*/

#include <SoftwareSerial.h>

#include <SPI.h>
#include "SdFat.h"
SdFat SD;

#define SD_CS_PIN SS
File myFile;

#define txPin    9   // Serial output
#define rxPin    8   // Serial input (unused, but required by the library)

// Set up a new serial port
SoftwareSerial ttlSerial =  SoftwareSerial(rxPin, txPin);

void setup()  // Setup code (called once on start-up)
{
    // Define pin modes
  pinMode(rxPin, INPUT);
  pinMode(txPin, OUTPUT);

  // Setup Arduino Serial Monitor
  Serial.begin(9600);
  while (!Serial);       // Wait until ready

  // Setup Serial Port for Data Output
  ttlSerial.begin(9600);
  while (!ttlSerial);    // Wait until ready

  // Initialize SD card
  Serial.println("\nInitializing SD card...");
  if (!SD.begin(SD_CS_PIN)) 
  {
    Serial.println("Initialization failed!");
    return;
  } 
  Serial.println("Initialization successful!");
  Serial.println("Starting file exfiltration...\n");
}

void loop() 
{
  // Open the file for reading
  // Note that only one file can be open at a time,
  // so you have to close this one before opening another
  myFile = SD.open("test.txt");
  
  if (myFile) 
  {
    while (myFile.available())  // For the entire file...
    {
      ttlSerial.write(myFile.read());  // Read byte and send to the serial terminal
    }

    myFile.close(); // Close the file
  } 
  else 
  {
    Serial.println("Error opening file!");  // if the file didn't open, print an error
  }
  
  ttlSerial.println();
}

